@@ -11,6 +11,11 @@ class Command:
         else:
             return False
 
+    def check(self, context):
+        return True
+
+    async def failed_check(self):
+        print('User not allowed to use this command.')
 
     async def run(self, context, call_arguments):
         await self.bot.send_message(f'{self.name} command works\ncommand arguments are: {call_arguments.join(" ")}', context.channel.id)
\ No newline at end of file
